# Lightspark Python SDK - v1.1.0

The Lightspark Python SDK provides a convenient way to interact with the Lightspark services from applications written in the Python language.

## Documentation

The documentation for this SDK (installation, usage, etc.) is available at https://app.lightspark.com/docs/sdk

## Sample code

For your convenience, we included an example that shows you how to use the SDK.
Open the file `example.py` and make sure to update the variables at the top of the page with your information, then run it using pipenv:

```python
pipenv install
pipenv run python -m examples.example
```
